Index: webrtc/modules/video_render/mac/video_render_agl.h |
diff --git a/webrtc/modules/video_render/mac/video_render_agl.h b/webrtc/modules/video_render/mac/video_render_agl.h |
index e1da8faf83b81da6c58944f9185b366631920545..c0a60597e98613d22ba1581a096cbd46e02f5466 100644 |
--- a/webrtc/modules/video_render/mac/video_render_agl.h |
+++ b/webrtc/modules/video_render/mac/video_render_agl.h |
@@ -29,6 +29,7 @@ |
#include <OpenGL/glu.h> |
#include <list> |
#include <map> |
+#include <memory> |
class VideoRenderAGL; |
@@ -142,8 +143,8 @@ class VideoRenderAGL { |
bool _fullScreen; |
int _id; |
webrtc::CriticalSectionWrapper& _renderCritSec; |
- // TODO(pbos): Remove scoped_ptr and use PlatformThread directly. |
- rtc::scoped_ptr<rtc::PlatformThread> _screenUpdateThread; |
+ // TODO(pbos): Remove unique_ptr and use PlatformThread directly. |
+ std::unique_ptr<rtc::PlatformThread> _screenUpdateThread; |
webrtc::EventWrapper* _screenUpdateEvent; |
bool _isHIViewRef; |
AGLContext _aglContext; |